==> haskell-parameterized-utils-2.1.10.0-104-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parameterized-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 parameterized-utils
version:              2.1.10.0
visibility:           public
id:                   parameterized-utils-2.1.10.0-KCRVPLkHb4tH20B5rLC9FE
key:                  parameterized-utils-2.1.10.0-KCRVPLkHb4tH20B5rLC9FE
license:              BSD-3-Clause
copyright:            ©2016-2022 Galois, Inc.
maintainer:           kquick@galois.com, rscott@galois.com
author:               Galois Inc.
stability:            stable
homepage:             https://github.com/GaloisInc/parameterized-utils
synopsis:
    Classes and data structures for working with data-kind indexed types

description:
    This package contains collection classes and type representations
    used for working with values that have a single parameter.  It'\''s
    intended for things like expression libraries where one wishes
    to leverage the Haskell type-checker to improve type-safety by encoding
    the object language type system into data kinds.

category:             Data Structures, Dependent Types
abi:                  cd378d8d5665b95007159783160f2920
exposed:              True
exposed-modules:
    Data.Parameterized Data.Parameterized.All Data.Parameterized.Axiom
    Data.Parameterized.BoolRepr Data.Parameterized.Classes
    Data.Parameterized.ClassesC Data.Parameterized.Compose
    Data.Parameterized.Context Data.Parameterized.Context.Safe
    Data.Parameterized.Context.Unsafe Data.Parameterized.Ctx
    Data.Parameterized.Ctx.Proofs Data.Parameterized.DataKind
    Data.Parameterized.DecidableEq Data.Parameterized.Fin
    Data.Parameterized.FinMap Data.Parameterized.FinMap.Safe
    Data.Parameterized.FinMap.Unsafe Data.Parameterized.HashTable
    Data.Parameterized.List Data.Parameterized.Map
    Data.Parameterized.NatRepr Data.Parameterized.Nonce
    Data.Parameterized.Nonce.Transformers
    Data.Parameterized.Nonce.Unsafe Data.Parameterized.Pair
    Data.Parameterized.Peano Data.Parameterized.Some
    Data.Parameterized.SymbolRepr Data.Parameterized.TH.GADT
    Data.Parameterized.TraversableF Data.Parameterized.TraversableFC
    Data.Parameterized.TraversableFC.WithIndex
    Data.Parameterized.Utils.BinTree Data.Parameterized.Utils.Endian
    Data.Parameterized.Vector Data.Parameterized.WithRepr

hidden-modules:       Data.Parameterized.NatRepr.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/parameterized-utils-2.1.10.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/parameterized-utils-2.1.10.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/parameterized-utils-2.1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-parameterized-utils
hs-libraries:         HSparameterized-utils-2.1.10.0-KCRVPLkHb4tH20B5rLC9FE
depends:
    base-4.17.2.1 base-orphans-0.9.3-45Lo9hTW9RW2jdrfbZEMaQ
    constraints-0.14.2-BzosEYfLBtf19uZHft3bw9 containers-0.6.7
    deepseq-1.4.8.0 ghc-prim-0.9.1
    hashable-1.4.6.0-Bdyeh8ev81I2bBqnptAVUL
    hashtables-1.4.2-L72KwBvOgrg4KDG4xPcDEv
    indexed-traversable-0.1.4-52OhEMiwF4u4EtkYVR4uVg
    lens-5.3.2-3lnPesktvu71I24tA5AXig mtl-2.2.2
    profunctors-5.6.3-B1puex7pinj8XdCtxpi2Qf template-haskell-2.19.0.0
    text-2.0.2 th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy
    vector-0.13.2.0-JPy5pohpq8EDknIfFhMz6E

haddock-interfaces:
    /usr/share/doc/haskell-parameterized-utils/html/parameterized-utils.haddock

haddock-html:         /usr/share/doc/haskell-parameterized-utils/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parameterized-utils-2.1.10.0-105-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-parameterized-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 parameterized-utils
version:              2.1.10.0
visibility:           public
id:                   parameterized-utils-2.1.10.0-8q1ZIkmfgZ4JiWLYsFdFNd
key:                  parameterized-utils-2.1.10.0-8q1ZIkmfgZ4JiWLYsFdFNd
license:              BSD-3-Clause
copyright:            ©2016-2022 Galois, Inc.
maintainer:           kquick@galois.com, rscott@galois.com
author:               Galois Inc.
stability:            stable
homepage:             https://github.com/GaloisInc/parameterized-utils
synopsis:
    Classes and data structures for working with data-kind indexed types

description:
    This package contains collection classes and type representations
    used for working with values that have a single parameter.  It'\''s
    intended for things like expression libraries where one wishes
    to leverage the Haskell type-checker to improve type-safety by encoding
    the object language type system into data kinds.

category:             Data Structures, Dependent Types
abi:                  a6002d386a0d7f701864c7983491ceb0
exposed:              True
exposed-modules:
    Data.Parameterized Data.Parameterized.All Data.Parameterized.Axiom
    Data.Parameterized.BoolRepr Data.Parameterized.Classes
    Data.Parameterized.ClassesC Data.Parameterized.Compose
    Data.Parameterized.Context Data.Parameterized.Context.Safe
    Data.Parameterized.Context.Unsafe Data.Parameterized.Ctx
    Data.Parameterized.Ctx.Proofs Data.Parameterized.DataKind
    Data.Parameterized.DecidableEq Data.Parameterized.Fin
    Data.Parameterized.FinMap Data.Parameterized.FinMap.Safe
    Data.Parameterized.FinMap.Unsafe Data.Parameterized.HashTable
    Data.Parameterized.List Data.Parameterized.Map
    Data.Parameterized.NatRepr Data.Parameterized.Nonce
    Data.Parameterized.Nonce.Transformers
    Data.Parameterized.Nonce.Unsafe Data.Parameterized.Pair
    Data.Parameterized.Peano Data.Parameterized.Some
    Data.Parameterized.SymbolRepr Data.Parameterized.TH.GADT
    Data.Parameterized.TraversableF Data.Parameterized.TraversableFC
    Data.Parameterized.TraversableFC.WithIndex
    Data.Parameterized.Utils.BinTree Data.Parameterized.Utils.Endian
    Data.Parameterized.Vector Data.Parameterized.WithRepr

hidden-modules:       Data.Parameterized.NatRepr.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/parameterized-utils-2.1.10.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/parameterized-utils-2.1.10.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/parameterized-utils-2.1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-parameterized-utils
hs-libraries:         HSparameterized-utils-2.1.10.0-8q1ZIkmfgZ4JiWLYsFdFNd
depends:
    base-4.17.2.1 base-orphans-0.9.3-21Kg0ZpixBhIWAAM72mV1W
    constraints-0.14.2-8BwdZPW78NmEcbjpNxA4Zj containers-0.6.7
    deepseq-1.4.8.0 ghc-prim-0.9.1
    hashable-1.4.6.0-2hEv5lQFD6LEJdTUNcXkaI
    hashtables-1.4.2-C3JdfY1CaajFPWO8zXY6BZ
    indexed-traversable-0.1.4-21HfwHBcrgA8B9HfAQ8T5X
    lens-5.3.2-LURSnBuXCqTHeh00mrfrRc mtl-2.2.2
    profunctors-5.6.3-CCfJI8tgRIPBp3AVzibRmu template-haskell-2.19.0.0
    text-2.0.2 th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy
    vector-0.13.2.0-HGgKaKiJszd4ty04a0OkB8

haddock-interfaces:
    /usr/share/doc/haskell-parameterized-utils/html/parameterized-utils.haddock

haddock-html:         /usr/share/doc/haskell-parameterized-utils/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
